@@ -2,7 +2,7 @@
  * DinkC script engine
 
  * Copyright (C) 1997, 1998, 1999, 2002, 2003  Seth A. Robinson
- * Copyright (C) 2005, 2007, 2008  Sylvain Beucler
+ * Copyright (C) 2005, 2007, 2008, 2014, 2015  Sylvain Beucler
 
  * This file is part of GNU FreeDink
 
@@ -24,11 +24,8 @@
 #ifndef _BGM_H
 #define _BGM_H
 
-extern int last_cd_track;
+extern /*bool*/int midi_active;
 
-extern int cdplaying();
-extern int killcd();
-extern int PlayCD(int cd_track);
 extern int something_playing(void);
 extern int PlayMidi(char *sFileName);
 extern int PauseMidi();
