@@ -2,7 +2,7 @@
  * Keyboard and joystick
 
  * Copyright (C) 1997, 1998, 1999, 2002, 2003  Seth A. Robinson
- * Copyright (C) 2005, 2007, 2008  Sylvain Beucler
+ * Copyright (C) 2005, 2007, 2008, 2009, 2010, 2014, 2015  Sylvain Beucler
 
  * This file is part of GNU FreeDink
 
@@ -24,10 +24,7 @@
 #ifndef _INPUT_H
 #define _INPUT_H
 
-#ifdef __cplusplus
-extern "C"
-{
-#endif
+#include "SDL.h"
 
 #define NB_BUTTONS 12
 
@@ -68,42 +65,29 @@ extern "C"
                                  // (used to compute .button and to release an arrow with the bow)
     // Note: also used by Dinkedit, but with fewer different actions
     
-    /* Only used in the editor (for now): */
-    /* State of the keyboard, SDL-supported keys */
-#if SDL_VERSION_ATLEAST(1, 3, 0)
-    /* SDL 1.3 TODO */
-#else
-    int keystate[SDLK_LAST]; /* current GetAsyncKeyState value, in
-    				cache */
-    int keyjustpressed[SDLK_LAST]; /* true if key was just pressed, false
-    				      if kept pressed or released */
-#endif
-
-    /* Idem, but with unicode characters - layout-independant */
-    char charstate[65536];
-    char charjustpressed[65536];
-    char key2char[65536]; /* to retrieve matching unicode on SDL_KEYUP,
-			     if possible */
-    Uint16 last_unicode; /* last character typed by the user, used for
-			    text input */
-    Uint16 last_nokey_unicode; /* char with no key match, so no KEYUP
-				  support - reset it next time */
-    
     int right,left,up,down; // is this arrow currently pressed?
     int rightd,leftd,upd,downd; // was this arrow just pressed (not maintained pressed)?
     int rightold,leftold,upold,downold; // copy of previous state (used to compute *d)
   };
   extern struct seth_joy sjoy;
+  extern /*bool*/int mouse1;
 
-  extern int GetKeyboard(int key);
-  extern void input_init(void);
-  extern void input_quit(void);
-  extern void input_set_default_buttons(void);
-  extern enum buttons_actions input_get_button_action(int button_index);
-  extern void input_set_button_action(int button_index, enum buttons_actions action_index);
+  /* Joystick */
+  extern /*BOOL*/int joystick;
+  extern SDL_Joystick* jinfo;
 
-#ifdef __cplusplus
-}
-#endif
+  extern void input_update(SDL_Event *ev);
+  extern void input_init();
+  extern void input_quit();
+  extern void input_set_default_buttons();
+  extern int input_get_button_action(int button_index);
+  extern void input_set_button_action(int button_index, int action_index);
+
+  extern void input_reset();
+
+  extern Uint8 input_getscancodestate(SDL_Scancode scancode);
+  extern /*bool*/int input_getscancodejustpressed(SDL_Scancode scancode);
+  extern Uint8 input_getcharstate(SDL_Keycode ch);
+  extern /*bool*/int input_getcharjustpressed(SDL_Keycode ch);
 
 #endif
