@@ -1,5 +1,5 @@
 #ifndef VGASYS_FON_H
 #define VGASYS_FON_H
-extern unsigned char vgasys_fon[6512];
+extern const unsigned char vgasys_fon[6512];
 #endif
 
